getStudyStatusList method
Get the status for the studies which run on this client device. Note that is the current status, and reflects the latest known status. If you want an updated status from the deployment service, use getStudyDeploymentStatus for each study.
Implementation
List<StudyStatus> getStudyStatusList() =>
studies.map((study) => study.status).toList();