removeStudy method

  1. @mustCallSuper
Future<void> removeStudy(
  1. String studyDeploymentId,
  2. String deviceRoleName
)

Remove the study with studyDeploymentId and deviceRoleName from this client manager.

Note that by removing a study, the deployment is not marked as stopped permanently in the deployment service. Hence, the study can later be added and deployed again using the addStudy and tryDeployment methods.

If a study deployment is to be permanently stopped, use the stopStudy method.

Implementation

@mustCallSuper
Future<void> removeStudy(
  String studyDeploymentId,
  String deviceRoleName,
) async {
  _checkConfiguration();

  var study = getStudy(studyDeploymentId, deviceRoleName);
  if (study != null) {
    repository.removeStudy(study);
  }
}