ClientRepository<TStudy extends Study<PrimaryDeviceDeployment>> class abstract interface

A repository which handles persisting the state of studies. Used by a ClientManager to store and retrieve information about the client device and the studies it is handling.

Properties

deviceRegistration DeviceRegistration?
The DeviceRegistration used to register the client in deployments.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addStudy(TStudy study) → void
Adds study to the repository.
getStudy(String studyDeploymentId, String deviceRoleName) → TStudy?
Return the study with studyDeploymentId and deviceRoleName, or null when no such study is found.
getStudyList() List<TStudy>
Return all studies in this repository. May be an empty list if no studies have been added.
hasStudy(TStudy study) bool
Is study in this repository?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeStudy(TStudy study) → void
Remove study which is already stored in the repository. In case study is not stored in this repository, nothing happens.
toString() String
A string representation of this object.
inherited
updateStudy(TStudy study) → void
Update a study which is already stored in the repository. In case study is not stored in this repository, nothing happens.

Operators

operator ==(Object other) bool
The equality operator.
inherited