addStudy abstract method

void addStudy(
  1. TStudy study
)

Adds study to the repository.

If study with the same study deployment id and device role name as study already exists in this repository, nothing happens. If a study needs to be updated, use the updateStudy method.

Implementation

void addStudy(TStudy study);