getStudyList abstract method
Return all studies in this repository. May be an empty list if no studies have been added.
Implementation
List<TStudy> getStudyList();
Return all studies in this repository. May be an empty list if no studies have been added.
List<TStudy> getStudyList();