removeStudy abstract method

void removeStudy(
  1. TStudy study
)

Remove study which is already stored in the repository. In case study is not stored in this repository, nothing happens.

Implementation

void removeStudy(TStudy study);