ConnectedDeviceDataCollector<TDeviceConfiguration extends DeviceConfiguration<TRegistration> , TRegistration extends DeviceRegistration> class
abstract
interface
Collects Data for a single connected device.
- Inheritance
-
- Object
- DeviceDataCollector
- ConnectedDeviceDataCollector
Properties
- canConnect → bool
-
Determines whether a connection can be made at this point in time to the device.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedDataTypes
→ Set<
DataType> -
The set of data types defining which data can be collected on this device.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited