canConnect property
bool
get
canConnect
Determines whether a connection can be made at this point in time to the device.
Implementation
bool get canConnect;
Determines whether a connection can be made at this point in time to the device.
bool get canConnect;