DeviceDataCollectorFactory class abstract

Provides a localDataCollector to collect data locally on the primary device and supports creating ConnectedDeviceDataCollector instances for connected devices.

Constructors

DeviceDataCollectorFactory([DeviceDataCollector? localDataCollector])

Properties

hashCode int
The hash code for this object.
no setterinherited
localDataCollector DeviceDataCollector?
The data collector for the primary device.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createConnectedDataCollector(String deviceType, DeviceRegistration deviceRegistration) ConnectedDeviceDataCollector<DeviceConfiguration<DeviceRegistration>, DeviceRegistration>?
Create a ConnectedDeviceDataCollector for a connected deviceType using connection options specified in deviceRegistration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited