createdOn property
DateTime
get
createdOn
The date and time when this study was created and added to the ClientManager.
Implementation
DateTime get createdOn => _createdOn;
The date and time when this study was created and added to the ClientManager.
DateTime get createdOn => _createdOn;