deviceRoleName property
String
get
deviceRoleName
The role name of the device in the deployment this study runtime participates in.
Implementation
String get deviceRoleName => _deviceRoleName;
The role name of the device in the deployment this study runtime participates in.
String get deviceRoleName => _deviceRoleName;