studyDeploymentId property
String
get
studyDeploymentId
The ID of the deployed study for which to collect data.
Implementation
String get studyDeploymentId => _studyDeploymentId;
The ID of the deployed study for which to collect data.
String get studyDeploymentId => _studyDeploymentId;