StudyDeploymentProxy class

Perform deployment actions for a Study on a client device.

Constructors

StudyDeploymentProxy(DeploymentService deploymentService)

Properties

deploymentService DeploymentService
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStudyDeploymentStatus(Study<PrimaryDeviceDeployment> study) Future<StudyDeploymentStatus?>
Get the deployment status for the study from the deployment service. This updates the deploymentStatus and sets the study status accordingly.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop(Study<PrimaryDeviceDeployment> study) Future<void>
Permanently stop this study.
toString() String
A string representation of this object.
inherited
tryDeployment(Study<PrimaryDeviceDeployment> study, DeviceRegistration registration) Future<void>
Tries to deploy the study if it's ready to be deployed by registering the client device using registration and verifying the study is ready for deployment on this device. In case already deployed, nothing happens.

Operators

operator ==(Object other) bool
The equality operator.
inherited