StudyStatusEvent<TStudy extends Study<PrimaryDeviceDeployment>> class

An event related to a running study.

Constructors

StudyStatusEvent(TStudy study, StudyStatusEventTypes event)
const

Properties

event StudyStatusEventTypes
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
study → TStudy
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited