CompletedTask class

Data about an interactive user task with taskName, which has been completed.

taskData holds the result of the task, or null if no result is collected.

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

CompletedTask({required String taskName, Data? taskData})
CompletedTask.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType DataType
The type of this data as a DataType.
no setterinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
recordId String?
Stable identifier of the source record, if available.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskData Data?
The result of the completed task, if any.
getter/setter pair
taskName String
The name of the task which was completed. This is the name of the task as specified in the study protocol.
getter/setter pair

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited