DEFAULT_ROLE_NAME constant
String
const DEFAULT_ROLE_NAME
The default role name for a custom protocol device.
Implementation
static const String DEFAULT_ROLE_NAME = 'Custom device';
The default role name for a custom protocol device.
static const String DEFAULT_ROLE_NAME = 'Custom device';