Data class

Holds data of a specific dataType. This is a base class and contains no data as such.

Inheritance
Implementers
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

Data()
Data.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType DataType
The type of this data as a DataType.
no setter
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setteroverride
recordId String?
Stable identifier of the source record, if available.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited