DiagnosisInput class

The diagnosis of a patient.

We are using the WHO ICD-11 classification.

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

DiagnosisInput({DateTime? effectiveDate, String? diagnosis, required String icd11Code, String? conclusion})
DiagnosisInput.fromJson(Map<String, dynamic> json)
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
conclusion ↔ String?
Any conclusion or notes from the physician.
getter/setter pair
dataType → DataType
The type of this data as a DataType.
no setterinherited
diagnosis ↔ String?
A free text description of the diagnosis.
getter/setter pair
effectiveDate ↔ DateTime?
The date this diagnosis was effective.
getter/setter pair
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
icd11Code ↔ String
The ICD-11 code of this diagnosis.
getter/setter pair
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
recordId → String?
Stable identifier of the source record, if available.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of this input data.
no setteroverride

Methods

equivalentTo(Data other) → bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited