EducationalDegreeInput class

Highest completed educational degree, mapped to the ISCED framework for cross-country comparability.

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

EducationalDegreeInput({required IscedLevel level, String? details})
EducationalDegreeInput.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType DataType
The type of this data as a DataType.
no setterinherited
details String?
Optional free-text details (e.g., subject, institution).
getter/setter pair
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
level IscedLevel
The ISCED level of the completed degree.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of this input data.
no setteroverride

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited