IscedLevel enum

The ISCED framework education levels.

Inheritance
Available extensions

Values

ISCED_0 → const IscedLevel

No formal education

ISCED_1 → const IscedLevel

Primary education

ISCED_2 → const IscedLevel

Lower secondary education

ISCED_3 → const IscedLevel

Upper secondary education

ISCED_4 → const IscedLevel

Post-secondary non-tertiary education

ISCED_5 → const IscedLevel

Short-cycle tertiary education

ISCED_6 → const IscedLevel

Bachelor or equivalent

ISCED_7 → const IscedLevel

Master or equivalent

ISCED_8 → const IscedLevel

Doctoral or equivalent

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IscedLevel>
A constant List of the values in this enum, in order of their declaration.