MonitoringTask class

A task which is used for monitoring the execution of the data sampling collecting data on CompletedTask, TriggeredTask, and Error. This task is not supposed to be executed as such, but allows the addition of such monitoring measure to be added to a protocol.

Inheritance
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

MonitoringTask({String? name, String? description, List<Measure>? measures})
Create a new monitoring task.
MonitoringTask.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
description String?
A description of this task, emphasizing the reason why the data is collected.
getter/setter pairinherited
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
measures List<Measure>?
The data which needs to be collected/measured passively as part of this task.
getter/setter pairinherited
name String
A name which uniquely identifies the task.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMeasure(Measure measure) → void
Add measure to this task.
inherited
addMeasures(Iterable<Measure> list) → void
Add a list of measures to this task.
inherited
getAllExpectedDataTypes() Set<String>
Get data types of all data which may be collected, either passively as part of task measures, or as the result of user interactions, for this task.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMeasure(Measure measure) → void
Remove measure from this task.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited