apiVersion property
The API version of this request as defined by CARP Core Kotlin.
Implementation
@override
String get apiVersion => DataStreamService.API_VERSION;
The API version of this request as defined by CARP Core Kotlin.
Implementation
String apiVersion = "1.0";