remainingDevicesToRegisterBeforeDeployment property
The role names of devices which need to be registered before this device can be declared as successfully deployed.
Implementation
List<String>? remainingDevicesToRegisterBeforeDeployment;
The role names of devices which need to be registered before this device can be declared as successfully deployed.
List<String>? remainingDevicesToRegisterBeforeDeployment;