remainingDevicesToRegisterToObtainDeployment property
The role names of devices which need to be registered before the deployment information for this device can be obtained.
Implementation
List<String>? remainingDevicesToRegisterToObtainDeployment;
The role names of devices which need to be registered before the deployment information for this device can be obtained.
List<String>? remainingDevicesToRegisterToObtainDeployment;