participantStatusList property
The list of all participants and their status in this study deployment.
Implementation
List<ParticipantStatus> participantStatusList = [];
The list of all participants and their status in this study deployment.
List<ParticipantStatus> participantStatusList = [];