protocol library

Implements open standards which can describe a study protocol, i.e., defining how a study should be run. Essentially, this subsystem has no technical dependencies on any particular sensor technology or application as it merely describes why, when, and what data should be collected.

Contain the the core CARP domain classes like StudyProtocol, TaskConfiguration, and Measure.

See the carp.protocols definition in Kotlin.

Classes

Add
An RPC request for ProtocolService.add.
AddVersion
An RPC request for ProtocolService.addVersion.
CreateCustomProtocol
An RPC request for ProtocolFactoryService.createCustomProtocol.
DeviceConnection
GetAllForOwner
An RPC request for ProtocolService.getAllForOwner.
GetBy
An RPC request for ProtocolService.getBy.
GetVersionHistoryFor
An RPC request for ProtocolService.getVersionHistoryFor.
ProtocolFactoryService
Factory methods to create a StudyProtocol according to predefined templates.
ProtocolService
Application service which allows managing (multiple versions of) StudyProtocols.
ProtocolServiceRequest
An abstract RPC request to a ProtocolService.
ProtocolVersion
Specifies a specific version for a StudyProtocol, identified by a tag.
StudyProtocol
A description of how a study is to be executed, defining the type(s) of primary device(s) (PrimaryDeviceConfiguration) responsible for aggregating data, the optional devices (DeviceConfiguration) connected to them, and the TaskControl's which lead to data collection on said devices.
UpdateParticipantDataConfiguration
An RPC request for ProtocolService.updateParticipantDataConfiguration.