removeDeviceAssignment method

void removeDeviceAssignment(
  1. PrimaryDeviceConfiguration<DeviceRegistration> device
)

Remove the primary device assignments and hence make it assigned to all roles.

Requires that device is part of this protocol.

Implementation

void removeDeviceAssignment(PrimaryDeviceConfiguration device) {
  assignedDevices ??= {};
  assert(
    primaryDevices.contains(device),
    "The device configuration is not part of this protocol.",
  );

  assignedDevices!.remove(device.roleName);
}