deploymentService property
DeploymentService
get
deploymentService
The application service through which study deployments, to be run on this client, can be managed and retrieved.
Implementation
DeploymentService get deploymentService =>
_deploymentService ??
(throw NotConfiguredException(
'ClientManager has not been configured yet. Call configure() first.',
));