updateStudy abstract method
void
updateStudy(
- TStudy study
Update a study which is already stored in the repository.
In case study is not stored in this repository, nothing happens.
Implementation
void updateStudy(TStudy study);