SmartphoneClient class
Allows managing studies on a smartphone.
- Inheritance
-
- Object
- ClientManager<
Smartphone, DeviceRegistration, Study< PrimaryDeviceDeployment> > - SmartphoneClient
Constructors
-
SmartphoneClient({ClientRepository<
Study< ? repository, DeploymentService? deploymentService, DeviceDataCollectorFactory? dataCollectorFactory})PrimaryDeviceDeployment> >
Properties
- dataCollectorFactory → DeviceDataCollectorFactory?
-
Determines which DeviceDataCollector to use to collect data locally on
this primary device and this factory is used to create
ConnectedDeviceDataCollector instances for connected devices.
no setterinherited
- deploymentService → DeploymentService
-
The application service through which study deployments, to be run on
this client, can be managed and retrieved.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConfigured → bool
-
Determines whether a DeviceRegistration has been configured for this client,
which is necessary to start adding studies.
no setterinherited
- proxy ↔ StudyDeploymentProxy?
-
getter/setter pairinherited
- registration → DeviceRegistration
-
The registration of this client.
no setterinherited
-
repository
→ ClientRepository<
Study< PrimaryDeviceDeployment> > -
Repository within which the state of this client is stored.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
studies
→ List<
Study< PrimaryDeviceDeployment> > -
Get the studies running on this client device.
no setterinherited
Methods
-
addStudy(
Study< PrimaryDeviceDeployment> study) → Future<Study< PrimaryDeviceDeployment> > -
Add a
studywhich needs to be executed on this client. No deployment is attempted yet.inherited -
configure(
{required DeviceRegistration registration, DeploymentService? deploymentService, DeviceDataCollectorFactory? dataCollectorFactory}) → Future< void> -
Configure this ClientManager by specifying a
registrationfor this client device.inherited -
getStudy(
String studyDeploymentId, String deviceRoleName) → Study< PrimaryDeviceDeployment> ? -
Get the study with
studyDeploymentIdanddeviceRoleNamefrom this client manager. Returns null if no such study has been added.inherited -
getStudyDeploymentStatus(
Study< PrimaryDeviceDeployment> study) → Future<StudyDeploymentStatus?> -
Get the deployment status for the
studyfrom the deployment service. This updates the study's deployment status and sets the study's status accordingly. Returns null if the deployment status could not be retrieved from the deployment service or if the study has not been added to this client manager.inherited -
getStudyStatusList(
) → List< StudyStatus> -
Get the status for the studies which run on this client device.
Note that is the current status, and reflects the latest known status.
If you want an updated status from the deployment service, use
getStudyDeploymentStatus for each study.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeStudy(
String studyDeploymentId, String deviceRoleName) → Future< void> -
Remove the study with
studyDeploymentIdanddeviceRoleNamefrom this client manager.inherited -
stopStudy(
String studyDeploymentId, String deviceRoleName) → Future< StudyStatus> -
Permanently stop collecting data for the study with id
studyDeploymentIdand mark it as stopped.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
tryDeployment(
String studyDeploymentId, String deviceRoleName) → Future< StudyStatus> -
Verifies whether the device is ready for deployment of the study runtime
identified by
studyDeploymentIdanddeviceRoleName, and in case it is, deploys. In case already deployed, nothing happens and the status of the deployment is returned.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited