StudyStatus enum
Describes the status of a Study.
This is based on the state diagram for Study State However, all the "Deploying" states have been collapsed into a single Deploying state.
If a study is in the Deploying state, the client can query the
DeviceDeploymentStatus.remainingDevicesToRegisterToObtainDeployment or the
DeviceDeploymentStatus.remainingDevicesToRegisterBeforeDeployment
of this device with deviceRoleName to understand what is holding the
deployment back.
Values
- DeploymentNotStarted → const StudyStatus
-
The study deployment process hasn't been started yet.
- DeploymentStatusAvailable → const StudyStatus
-
The study has been deployed in the deployment service and its status is available.
- DeploymentNotAvailable → const StudyStatus
-
The study deployment is not available.
- Deploying → const StudyStatus
-
The study deployment process is ongoing, but not yet completed.
According to the state diagram for Study State, this state combines the following states:
- AwaitingOtherDeviceRegistrations - Deployment information for this primary device cannot be retrieved yet since other primary devices in the study deployment need to be registered first.
- AwaitingDeviceDeployment - The deployment service is ready to deliver the deployment information to this primary device.
- DeviceDeploymentReceived - Deployment information has been received.
- RegisteringDevices - Deployment can complete after all devices have been registered.
- AwaitingOtherDeviceDeployments - Deployment for this primary device has completed, but awaiting deployment of other devices in this study deployment.
- Deployed → const StudyStatus
-
Deployment has been successfully completed. The PrimaryDeviceDeployment has been retrieved and ready to execute the study.
- Running → const StudyStatus
-
The study is started and ready to sample data on the client.
- Stopped → const StudyStatus
-
The study has been stopped, either from this client or via the deployment service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StudyStatus> - A constant List of the values in this enum, in order of their declaration.